diff --git a/core/modules/system/tests/modules/system_incompatible_php_version_test/system_incompatible_php_version_test.info.yml b/core/modules/system/tests/modules/system_incompatible_php_version_test/system_incompatible_php_version_test.info.yml
new file mode 100644
index 0000000..a3a26ee
--- /dev/null
+++ b/core/modules/system/tests/modules/system_incompatible_php_version_test/system_incompatible_php_version_test.info.yml
@@ -0,0 +1,7 @@
+name: 'System incompatible PHP version test'
+type: module
+description: 'Support module for testing system dependencies.'
+package: Testing
+version: VERSION
+core: 8.x
+php: 6502
diff --git a/core/modules/system/tests/modules/system_test/system_test.module b/core/modules/system/tests/modules/system_test/system_test.module
index eef3516..9ae8c5a 100644
--- a/core/modules/system/tests/modules/system_test/system_test.module
+++ b/core/modules/system/tests/modules/system_test/system_test.module
@@ -66,6 +66,7 @@ function system_test_system_info_alter(&$info, Extension $file, $type) {
     'system_incompatible_core_version_dependencies_test',
     'system_incompatible_module_version_test',
     'system_incompatible_core_version_test',
+    'system_incompatible_php_version_test',
   ))) {
     $info['hidden'] = FALSE;
   }

diff --git a/core/modules/system/src/Tests/Module/DependencyTest.php b/core/modules/system/src/Tests/Module/DependencyTest.php
index e9162a8..9b6f3f5 100644
--- a/core/modules/system/src/Tests/Module/DependencyTest.php
+++ b/core/modules/system/src/Tests/Module/DependencyTest.php
@@ -96,7 +96,22 @@ function testIncompatibleCoreVersionDependency() {
   }
 
   /**
-   * Tests enabling a module that depends on a module which fails hook_requirements().
+   * Tests users are informed if the PHP dependency requirements of
+   * a module are not met.
+   */
+  public function testIncompatiblePhpVersionDependency() {
+    $this->drupalGet('admin/modules');
+    $this->assertRaw(t('This module requires PHP version @php_required and is incompatible with PHP version @php_version.', array(
+      '@php_required' => '6502.*',
+      '@php_version' => phpversion(),
+    )), 'User is informed when a module that depends on a module with an incompatible PHP version.');
+    $checkbox = $this->xpath('//input[@type="checkbox" and @disabled="disabled" and @name="modules[Testing][system_incompatible_core_version_dependencies_test][enable]"]');
+    $this->assert(count($checkbox) == 1, 'Checkbox for the module is disabled.');
+  }
+
+  /**
+   * Tests enabling a module that depends on a module which fails
+   * hook_requirements().
    */
   function testEnableRequirementsFailureDependency() {
     \Drupal::service('module_installer')->install(array('comment'));